==> xs2a-impl-4.1-sources.jar: de/adorsys/psd2/xs2a/web/validator/body/cancelpayment/CancelPaymentBodyValidatorImpl.java <==
/*
 * Copyright 2018-2019 adorsys GmbH & Co KG
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package de.adorsys.psd2.xs2a.web.validator.body.cancelpayment;

import de.adorsys.psd2.xs2a.exception.MessageError;
import de.adorsys.psd2.xs2a.web.validator.body.TppRedirectUriBodyValidatorImpl;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;

import javax.servlet.http.HttpServletRequest;

@Component
public class CancelPaymentBodyValidatorImpl implements CancelPaymentBodyValidator {

    private TppRedirectUriBodyValidatorImpl tppRedirectUriBodyValidator;

    @Autowired
    public CancelPaymentBodyValidatorImpl(TppRedirectUriBodyValidatorImpl tppRedirectUriBodyValidator) {
        this.tppRedirectUriBodyValidator = tppRedirectUriBodyValidator;
    }

    @Override
    public void validate(HttpServletRequest request, MessageError messageError) {
        tppRedirectUriBodyValidator.validate(request, messageError);
    }
}

==> xs2a-impl-4.11-sources.jar: de/adorsys/psd2/xs2a/web/validator/body/cancelpayment/CancelPaymentBodyValidatorImpl.java <==
/*
 * Copyright 2018-2019 adorsys GmbH & Co KG
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package de.adorsys.psd2.xs2a.web.validator.body.cancelpayment;

import de.adorsys.psd2.xs2a.exception.MessageError;
import de.adorsys.psd2.xs2a.web.validator.body.TppRedirectUriBodyValidatorImpl;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;

import javax.servlet.http.HttpServletRequest;

@Component
public class CancelPaymentBodyValidatorImpl implements CancelPaymentBodyValidator {

    private TppRedirectUriBodyValidatorImpl tppRedirectUriBodyValidator;

    @Autowired
    public CancelPaymentBodyValidatorImpl(TppRedirectUriBodyValidatorImpl tppRedirectUriBodyValidator) {
        this.tppRedirectUriBodyValidator = tppRedirectUriBodyValidator;
    }

    @Override
    public MessageError validate(HttpServletRequest request, MessageError messageError) {
        return tppRedirectUriBodyValidator.validate(request, messageError);
    }
}
